;;; Directory Local Variables
;;; For more information see (info "(emacs) Directory Variables")

;; see https://www.compart.com/en/unicode/U+xxxx

((coq-mode
  (company-coq-dir-local-symbols .
   (("`&`" . 8745)  ;; ∩ U+2229
    ("`|`" . 8746)  ;; ∪ U+222A
    ("set0" . 8709) ;; ∅ U+2205
    ("`<`" . 8842) ;; ⊊ U+228A
    ("`<=`" . 8838) ;; ⊆ U+2286
    ("`*`" . ?×) ;; × U+00D7
    ("\\in" . ?∈) ;; ∈ U+2208
    ("\\notin" . ?∉) ;; ∉ U+2209
    ("^\\+" . ?⁺) ;; ⁺ U+207A
    ("^\\-" . ?⁻) ;; ⁻ U+207B
))))
